# Kobold
- [Kobold](https://github.com/KoboldAI/KoboldAI-Client)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Quick Start Guide
_Note: AI_MODEL should stay `default` unless there is a folder in `prompts` specific to the model that you're using. You can also create one and add your own prompts._

### Update your agent settings
1. Set `AI_MODEL` to `default` or the name of the model from the `prompts` folder.
2. Set `AI_PROVIDER_URI` to `http://localhost:5050/api/v1`, or the URI of your Kobold server. 
